pub struct CalibrationService { /* private fields */ }Implementations
Sourceimpl CalibrationService
impl CalibrationService
Sourcepub fn new(store: Arc<dyn NodeStore>) -> Self
pub fn new(store: Arc<dyn NodeStore>) -> Self
Create a calibration service backed by the configured node store.
Sourcepub async fn calibrate_async(
&self,
session_id: &str,
stability: f32,
friction: f32,
logic: f32,
autonomy: f32,
trigger: &str,
) -> Result<CalibrationResult>
pub async fn calibrate_async( &self, session_id: &str, stability: f32, friction: f32, logic: f32, autonomy: f32, trigger: &str, ) -> Result<CalibrationResult>
Persist a calibration point and return drift analysis vs prior state.